/******************************************************************************
 * File     :  timer0.c
 * Purpose  :  Timer0 Demo
 * Author   :  Prajin Palangsantikul
 * E-mail   :  prajin@appsofttech.com
 * Release  :  PCW Compiler 3.180
 * Copyright (c) 2004 APPSOFTTECH CO.,LTD.
 *****************************************************************************/

#define _PIC16F877_           // Use PIC16F877 device

#ifdef _PIC16F877_
#include <16F877.h>           // Standard Header file for the PIC16F877 device
#define  TxD         PIN_C6   // Define Transmitted Data
#define  RxD         PIN_C7   // Define Received Data
#define  CLOCK_SP    20000000 // Clock Speed(Hz)

#else
#include <16F628.h>           // Standard Header file for the PIC16F628 device
#define  TxD         PIN_A2   // Define Transmitted Data
#define  RxD         PIN_A3   // Define Received Data
#define  CLOCK_SP    4000000  // Clock Speed(Hz)

#endif

// Device Specification
#fuses HS                     // Oscillator mode HS
#fuses NOLVP, NOWDT           // No Low Voltage Program, No Watchdog timer
#fuses NOPROTECT              // Code no protection
#use delay (clock=CLOCK_SP)   // Use built-in function: delay_ms() & delay_us()
#use rs232(baud=9600, xmit=TxD,rcv=RxD) // Use serial I/O port (RS232)


/***********************************************************************
 * FUNCTION:    Main
 * DESCRIPTION: This is the main entry point for the program.
 * PARAMETERS:  nothing
 * RETURNED:    nothing
 ***********************************************************************/
void main(void) {

   long time;

   setup_timer_0(RTCC_INTERNAL | RTCC_DIV_2);
   puts("RTCC_INTERNAL | RTCC_DIV_2");
   set_timer0(0);
   delay_cycles(18); // Same as a 18 NOP
   time = get_timer0();
   printf("Time : %lu us\r\n",time);

   setup_timer_0(RTCC_INTERNAL | RTCC_DIV_4);
   puts("RTCC_INTERNAL | RTCC_DIV_4");
   set_timer0(0);
   delay_cycles(18); // Same as a 18 NOP
   time = get_timer0();
   printf("Time : %lu us\r\n",time);
}
